@@ -18,14 +18,10 @@
 #include <kglobal.h>
 #include <kiconloader.h>
 
-#include "ktapp.xpm"
-#include "ktmapp.xpm"
 #include "ktuser.xpm"
 #include "ktmuser.xpm"
 #include "ktsystem.xpm"
 #include "ktmsystem.xpm"
-#include "ktfolder.xpm"
-#include "ktmfolder.xpm"
 #include "ktvariable.xpm"
 #include "ktmvariable.xpm"
 #include "kthome.xpm"
@@ -38,7 +34,6 @@
 #include "ktmshell.xpm"
 #include "kttask.xpm"
 #include "ktmtask.xpm"
-#include "ktfilesave.xpm"
 
 QPixmap KTIcon::getMiniIcon(const QString& name)
 {
@@ -50,44 +45,12 @@ QPixmap KTIcon::getIcon(const QString& name)
   return BarIcon(name);
 }
 
-QPixmap KTIcon::save()
-{
-  // return (const char**)ktfilesave;
-  // why do they keep putting filesave.xpm in and out?
-  return getIcon("filesave.xpm");
-}
-
-QPixmap KTIcon::print()
-{
-  return getIcon("fileprint.xpm");
-}
-
-QPixmap KTIcon::cut()
-{
-  return getIcon("editcut.xpm");
-}
-
-QPixmap KTIcon::copy()
-{
-  return getIcon("editcopy.xpm");
-}
-
-QPixmap KTIcon::paste()
-{
-  return getIcon("editpaste.xpm");
-}
-
-QPixmap KTIcon::help()
-{
-  return getIcon("help.xpm");
-}
-
 QPixmap KTIcon::application(bool mini)
 {
   if (mini)
-    return (const char**)ktmapp;
+    return getMiniIcon("kcron");
   else
-    return (const char**)ktapp;
+    return getIcon("kcron");
 }
 
 QPixmap KTIcon::system(bool mini)
@@ -109,9 +72,9 @@ QPixmap KTIcon::user(bool mini)
 QPixmap KTIcon::variables(bool mini)
 {
   if (mini)
-    return (const char**)ktmfolder;
+    return getMiniIcon("folder");
   else
-    return (const char**)ktfolder;
+    return getIcon("folder");
 }
 
 QPixmap KTIcon::variable(bool mini)
@@ -157,9 +120,9 @@ QPixmap KTIcon::path(bool mini)
 QPixmap KTIcon::tasks(bool mini)
 {
   if (mini)
-    return (const char**)ktmfolder;
+    return getMiniIcon("folder");
   else
-    return (const char**)ktfolder;
+    return getIcon("folder");
 }
 
 QPixmap KTIcon::task(bool mini)
