@@ -16,11 +16,14 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#ifdef __DECCXX
+#include <config.h>
+
+#ifdef HAVE_SSTREAM
 #include <sstream>
 #else
 #include <strstream.h>
 #endif
+
 #include <string>
 
 #include <qstring.h>
@@ -76,6 +79,7 @@ void KTView::refresh()
   listView->setFrameStyle(QListView::Panel | QListView::Sunken);
   listView->setRootIsDecorated(true);
   listView->setAllColumnsShowFocus(true);
+  listView->setShowSortIndicator(true);
 
   const CTHost& cth(ktapp->getCTHost());
 
@@ -270,8 +274,7 @@ void KTView :: pageHeading (KTListItem* user, KTPrint &printer) const
 
 void KTView :: pageFooter (KTListItem* user, KTPrint &printer) const
 {
-  //This function will be a lot cleaner when gcc supports ostringstream.
-#ifdef __DECCXX
+#ifdef HAVE_SSTREAM
   ostringstream oss;
 #else
   char buffer[4096];
