@@ -1,4 +1,4 @@
-// $Id: BackupDlg.cpp,v 1.21 2002/01/29 04:13:31 widman Exp $
+// $Id: BackupDlg.cpp,v 1.22 2002/08/11 09:00:12 binner Exp $
 //
 // KDat - a tar-based DAT archiver
 // Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
@@ -127,7 +127,7 @@ BackupDlg::BackupDlg( const QString & archiveName, const QString & workingDir, c
 
     _log = new LoggerWidget( i18n( "Backup log:" ), this );
 
-    _ok = new QPushButton( i18n( "OK" ), this );
+    _ok = new QPushButton( i18n( "&OK" ), this );
     _ok->setFixedSize( 80, _ok->sizeHint().height() );
     connect( _ok, SIGNAL( clicked() ), this, SLOT( slotOK() ) );
     _ok->setEnabled( FALSE );
@@ -137,7 +137,7 @@ BackupDlg::BackupDlg( const QString & archiveName, const QString & workingDir, c
     connect( _save, SIGNAL( clicked() ), _log, SLOT( save() ) );
     _save->setEnabled( FALSE );
 
-    _abort = new QPushButton( i18n( "Abort" ), this );
+    _abort = new QPushButton( i18n( "&Abort" ), this );
     _abort->setFixedSize( 80, _abort->sizeHint().height() );
     connect( _abort, SIGNAL( clicked() ), this, SLOT( slotAbort() ) );
 
