@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 #include <qlabel.h>
 #include <qlayout.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "File.h"
 #include "TapeFileInfoWidget.h"
@@ -120,7 +121,7 @@ void TapeFileInfoWidget::setFile( File* file )
     _endRecord->setText( Util::bytesToString( _file->getEndRecord() ) );
 
     if ( _file->isDirectory() ) {
-        QListIterator<Range> it( _file->getRanges() );
+        QPtrListIterator<Range> it( _file->getRanges() );
         int records = 0;
         for ( ; it.current(); ++it ) {
             records += it.current()->getEnd() - it.current()->getStart();
