@@ -1,4 +1,4 @@
-// $Id: VerifyDlg.cpp,v 1.22 2002/01/31 15:45:38 widman Exp $
+// $Id: VerifyDlg.cpp,v 1.23 2002/08/11 09:00:12 binner Exp $
 //
 // KDat - a tar-based DAT archiver
 // Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
@@ -135,17 +135,17 @@ VerifyDlg::VerifyDlg( const QString & workingDir, int fileno, const RangeList& r
         _log = new LoggerWidget( i18n( "Verify log:" ), this );
     }
 
-    _ok = new QPushButton( i18n( "OK" ), this );
+    _ok = new QPushButton( i18n( "&OK" ), this );
     _ok->setFixedSize( 80, _ok->sizeHint().height() );
     connect( _ok, SIGNAL( clicked() ), this, SLOT( slotOK() ) );
     _ok->setEnabled( FALSE );
 
-    _save = new QPushButton( i18n( "Save Log..." ), this );
+    _save = new QPushButton( i18n( "&Save Log..." ), this );
     _save->setFixedSize( 80, _save->sizeHint().height() );
     connect( _save, SIGNAL( clicked() ), _log, SLOT( save() ) );
     _save->setEnabled( FALSE );
 
-    _abort = new QPushButton( i18n( "Abort" ), this );
+    _abort = new QPushButton( i18n( "&Abort" ), this );
     _abort->setFixedSize( 80, _abort->sizeHint().height() );
     connect( _abort, SIGNAL( clicked() ), this, SLOT( slotAbort() ) );
 
