@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 #define _VerifyDlg_h_
 
 #include <qdialog.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 #include "Range.h"
 
