@@ -70,9 +70,9 @@ VerifyOptDlg::VerifyOptDlg( const QString & def, const QStringList& files, bool
     QListBox* fileList = new QListBox( this );
     fileList->insertStringList(files);
 
-    QPushButton* ok     = new QPushButton( i18n( "OK" ), this );
+    QPushButton* ok     = new QPushButton( i18n( "&OK" ), this );
     ok->setFixedSize( 80, ok->sizeHint().height() );
-    QPushButton* cancel = new QPushButton( i18n( "Cancel" ), this );
+    QPushButton* cancel = new QPushButton( i18n( "&Cancel" ), this );
     cancel->setFixedSize( 80, cancel->sizeHint().height() );
 
     QVBoxLayout* l1 = new QVBoxLayout( this, 8, 4 );
