@@ -92,10 +92,21 @@
 
 #include <sys/types.h>
 #include <sys/ioctl.h>
+
+
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
 #ifdef TIME_WITH_SYS_TIME
-  #include <sys/time.h>
+#include <time.h>
 #endif
+#else
+#include <time.h>
+#endif
+
 #include <sys/resource.h>
+
+
+
 #ifdef HAVE_SYS_STROPTS_H
 #include <sys/stropts.h>
 #define _NEW_TTY_CTRL
@@ -247,7 +258,7 @@ void TEPty::donePty()
   }
 #endif
   if (needGrantPty) chownpty(fd,FALSE);
-  kdDebug() << "CLOSE........................\n";
+  //  kdDebug() << "CLOSE........................\n";
   close(fd);
   emit done(status);
 
