@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: debDpkgInterface.cpp,v 1.14 2001/12/19 11:21:08 binner Exp $
+//      $Id: debDpkgInterface.cpp,v 1.15 2002/08/15 16:06:16 binner Exp $
 //
 // Author: Toivo Pedaste
 //
@@ -47,15 +47,15 @@ DEBDPKG::DEBDPKG():DEB()
   locatedialog->cLocations(3, 2,  this, i18n("L"),
 			   "Deb", "*.deb",
 			   i18n("Version\nArchitecture"),
-			   i18n("Location of base directory of Debian distribution"),
+			   i18n("Location of Base Directory of Debian Distribution"),
 			   "stable frozen unstable\ni386 alpha sparc powerpc arm m68k");
   locatedialog->pLocations(3, 6, this, i18n("P"),
 			   "Deb", "*.deb Packages Packages.gz status available",
-			   i18n("Location of 'Packages' files for sections of Debian distributions"),
-			   i18n("Location of base directory of Debian distribution"));
+			   i18n("Location of 'Packages' Files for Sections of Debian Distributions"),
+			   i18n("Location of Base Directory of Debian Distribution"));
   locatedialog->dLocations(2, 6, this, i18n("D"),
 			   "Deb", "*.deb",
-			   i18n("Location of directories containing Debian packages"));
+			   i18n("Location of Directories Containing Debian Packages"));
   connect(locatedialog,SIGNAL(returnVal(LcacheObj *)),
 	  this,SLOT(setAvail(LcacheObj *)));
   locatedialog->apply_slot();
