@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: kplview.h,v 1.5 2000/06/11 15:18:15 toivo Exp $ 
+//      $Id: kplview.h,v 1.5.10.1 2003/03/13 00:05:21 rnolden Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -11,8 +11,8 @@
 
 // Qt Headers
 #include <qframe.h>
-#include <qpushbt.h>
-#include <qlist.h>
+#include <qpushbutton.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <qlayout.h>
 
