@@ -1,4 +1,4 @@
-/* 	$Id: rpmInstall.h,v 1.7 2001/01/01 05:54:05 toivo Exp $	 */
+/* 	$Id: rpmInstall.h,v 1.8 2001/07/09 21:43:10 bero Exp $	 */
 #ifndef _H_INSTALL
 #define _H_INSTALL
 
@@ -32,8 +32,13 @@ int doSourceInstall(const char * prefix, const char * arg, const char ** specFil
                     char ** cookie);
 
 void printDepFlags(FILE * f,  QString s, const char * version, int flags);
+#if RPM_V1 < 4 || (RPM_V1 == 4 && RPM_V2 == 0 && RPM_V3 < 3)
 QString KprintDepProblems(FILE * f, struct rpmDependencyConflict * conflicts,
                              int numConflicts);
+#else
+QString KprintDepProblems(FILE * f, rpmDependencyConflict conflicts,
+                             int numConflicts);
+#endif
 #define FREE(x) { if (x) free((void *)x); x = NULL; }       
 
 #endif
