@@ -1,10 +1,10 @@
-/* 	$Id: rpmVerify.h,v 1.4 1999/07/13 15:30:29 toivo Exp $	 */
+/* 	$Id: rpmVerify.h,v 1.5.8.1 2003/03/13 00:05:21 rnolden Exp $	 */
 
 #ifndef H_VERIFY
 #define H_VERIFY
 
 #include "../config.h"
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstringlist.h>
 
 #include <rpm/rpmlib.h>
@@ -26,6 +26,6 @@ enum verifysources { VERIFY_PATH, VERIFY_PACKAGE, VERIFY_EVERY, VERIFY_RPM,
 			VERIFY_GRP };
 
 int doVerify(const char * prefix, enum verifysources source, const QStringList &argv,
-	      int verifyFlags, QStringList *result);
+	      int verifyFlags, QStringList &result);
 
 #endif
