@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: search.h,v 1.7 2000/09/01 20:19:46 waba Exp $ 
+//      $Id: search.h,v 1.9.6.1 2003/03/13 00:05:21 rnolden Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -11,22 +11,16 @@
 // Standard Headers
 #include <stdio.h>
 
-// Qt Headers
-#include <qdir.h>
-#include <qwidget.h>
-#include <qframe.h>
-#include <qlabel.h>
-#include <qfiledlg.h> 
-#include <qgrpbox.h> 
-#include <qchkbox.h>
-#include <qlayout.h> 
+
+class QLineEdit;
+class QCheckBox;
 
 // KDE headers
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmenubar.h>
-#include <kbuttonbox.h> 
+#include <kdialogbase.h>
 
-class Search : public QDialog
+class Search : public KDialogBase
 {
   Q_OBJECT
 
@@ -34,20 +28,12 @@ public:
 
   Search ( QWidget *parent = 0, const char * name=0);
   ~Search(); 
-  void resizeEvent(QResizeEvent *);
 
 private:
-  QPushButton *ok, *cancel;
   QCheckBox *substr;
   QCheckBox *wrap;
-  QGroupBox *frame1;
   QLineEdit *value;
 
-  QVBoxLayout* vl;
-  QVBoxLayout* vtop, vf;
-  QHBoxLayout* hc;
-  KButtonBox* hb;
-
 signals:
     void search_signal();
     void search_done_signal();
@@ -55,5 +41,6 @@ signals:
 public slots:
     void done_slot();
     void ok_slot();
+    void textChanged(const QString &);
 };
 #endif
