@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: updateLoc.cpp,v 1.33 2001/05/30 20:27:15 waba Exp $ 
+//      $Id: updateLoc.cpp,v 1.36.2.1 2002/12/13 15:20:22 toivo Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -45,7 +45,7 @@ dpanel::dpanel(updateLoc *upd,  QString Pfilter, QWidget *parent,
     pack->addWidget(pent,0);
 
     if (bsubdirs) {
-      psubdirs = new QCheckBox(i18n("SubDirs"),this);
+      psubdirs = new QCheckBox(i18n("Subdirectories"),this);
       psubdirs->setFixedSize(psubdirs->sizeHint());
       pack->addWidget(psubdirs,0);
     }
@@ -134,7 +134,7 @@ void dpanel::fileOpen()
   }
 
   KURL url =  KFileDialog::getOpenURL
-    (st, filter, 0, i18n("Package file"));
+    (st, filter, 0, i18n("Package File"));
   
   if( url.isEmpty() )
     return;
@@ -153,12 +153,13 @@ void dpanel::dirOpen()
   }
 
   QString dir =  KFileDialog::getExistingDirectory
-    (st, 0, i18n("Package archive"));
+    (st, 0, i18n("Package Archive"));
   
   if (dir.isEmpty())
     return;
 
-  KURL url = KURL(dir);
+  KURL url;
+  url.setPath(dir);
 
   if( url.isEmpty() )
     return;
@@ -295,11 +296,10 @@ void updateLoc::applyS(LcacheObj *slist)
       // create cache object corresponding to this entry
       if (dp[i]->getUse()) {
 	t = dp[i]->getText();
-	//		printf("t=%i cn=%s %s\n",i,cn.ascii(),t.ascii());
 	if (!t.isEmpty()) {
-	  if (t.left(5) == "file:") {
-	    t.remove(0,5);
-	  } 
+	  //	  if (t.left(5) == "file:") {
+	  //	    t.remove(0,5);
+	  //	  } 
 	  CObj = new cacheObj(haveBase ? base->getText() : QString::null,
 			      t, cn + pn.setNum(i), "", dp[i]->getSubdirs());
 	  slist->append(CObj);
