@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: updateLoc.h,v 1.17 2002/04/22 18:47:07 arbab Exp $ 
+//      $Id: updateLoc.h,v 1.17.2.1 2003/03/13 00:05:21 rnolden Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -16,7 +16,7 @@
 #include <qwidget.h>
 #include <qframe.h>
 #include <qlabel.h>
-#include <qfiledlg.h> 
+#include <qfiledialog.h> 
 #include <qgroupbox.h> 
 #include <qcheckbox.h>
 #include <qlayout.h> 
