@@ -2,7 +2,7 @@
                           About.h  -  description
                              -------------------
     begin                : Sun Oct 3 1999
-    copyright            : (C) 1997-99 by Peter Putzer
+    copyright            : (C) 1997-2000 by Peter Putzer
     email                : putzer@kde.org
  ***************************************************************************/
 
@@ -21,8 +21,6 @@
 #ifndef KSV_ABOUT_H
 #define KSV_ABOUT_H
 
-#pragma interface
-
 #include <kdialogbase.h>
 
 class QString;
@@ -35,11 +33,14 @@ public:
   static AboutDlg* self ();
   virtual ~AboutDlg();
 
-private:
-  AboutDlg (QWidget* parent = 0L);
-
 private slots:
-  void callURL (const QString&);
+  void callMailer (const QString& url);
+  void openHomePage (const QString& url);
+
+private:
+  AboutDlg (QWidget* parent);
+
+  QString mAppName;
 };
 
 #endif
