@@ -27,7 +27,6 @@
 #include <qprogressdialog.h>
 #include <qkeycode.h>
 #include <qmessagebox.h>
-#include <qtmultilineedit.h>
 #include <qgroupbox.h>
 #include <qaccel.h>
 #include <qscrollbar.h>
@@ -963,7 +962,7 @@ void KSVContent::multiplexEnabled (bool val)
       else
       {
 	KMessageBox::information (kapp->mainWidget(),
-				  i18n ("<p>Sorry, you do not have the right permissions "   \
+				  i18n ("<p>You do not have the right permissions "   \
 					"to edit your system's init configuration. </p>"     \
 					"However, you are free to browse the runlevels.</p>" \
 					"<p>If you really want to edit the "                 \
@@ -975,7 +974,7 @@ void KSVContent::multiplexEnabled (bool val)
 					"due to security issues.</p>")
 				  .arg (kapp->aboutData()->programName())
 				  .arg (kapp->aboutData()->programName()),
-				  i18n("Not Enough Permissions"),
+				  i18n("Insufficient Permissions"),
 				  ksv::notifications[ksv::RunlevelsReadOnly]);
       }
 
