@@ -3,7 +3,7 @@
 #ifndef KSVAPPLICATION_H
 #define KSVAPPLICATION_H
 
-#include <kuniqueapp.h>
+#include <kuniqueapplication.h>
 
 class KSVApplication : public KUniqueApplication
 {
