@@ -14,11 +14,12 @@
 #include <qheader.h>
 #include <qpixmapcache.h>
 #include <qbitmap.h>
+#include <qcursor.h>
 #include <qcolor.h>
 #include <qcstring.h>
 #include <qlabel.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kpopupmenu.h>
 #include <kglobal.h>
 #include <klocale.h>
@@ -109,14 +110,14 @@ void KSVItem::paintCell (QPainter* p, const QColorGroup& cg, int column, int wid
     case SortNumber:
       p->setFont (mConfig->numberFont());
       break;
-      
+
     case ServiceName:
       p->setFont (mConfig->serviceFont());
       break;
     }
 
   QColorGroup colors = cg;
-  
+
   if (mData->newEntry())
 	{
 	  colors.setColor (QColorGroup::Text, mNewNormalColor);
@@ -207,7 +208,7 @@ QPixmap KSVItem::paintDragIcon (const QFont& font, const QColorGroup&) const
   p.fillRect (0, 0, width, height, brush);
 
   p.end();
-  
+
   result.setMask(mask);
   result.setOptimization(QPixmap::BestOptim);
   return result;
@@ -293,7 +294,7 @@ KSVDragList::KSVDragList ( QWidget* parent, const char* name )
 	mCommonToolTips (true)
 {
   // add tooltips
-  new KDLToolTip (this);
+  toolTip=new KDLToolTip (this);
 
   setDragEnabled (true);
   setDragAutoScroll(true);
@@ -303,13 +304,13 @@ KSVDragList::KSVDragList ( QWidget* parent, const char* name )
   QHeader* h = header();
   h->setClickEnabled (false);
 
-  addColumn (i18n("Nr")); // SortNumber
+  addColumn (i18n("No.")); // SortNumber
   //  setColumnWidthMode (KSVItem::SortNumber, Manual);
   addColumn (""); // Icon
 //   setColumnWidthMode (KSVItem::Icon, Manual);
   addColumn (i18n("Name")); // ServiceName
 //   setColumnWidthMode (KSVItem::ServiceName, Manual);
-  
+
   h->setResizeEnabled (false, KSVItem::Icon);
 
   setShowSortIndicator (false);
@@ -341,6 +342,7 @@ KSVDragList::~KSVDragList()
   delete mDragMenu;
   delete mDragCopyMenu;
   delete mDragMoveMenu;
+  delete toolTip;
 }
 
 void KSVDragList::initItem (QString file, QString path, QString name, Q_INT8 nr)
@@ -364,7 +366,7 @@ void KSVDragList::initItem (QString file, QString path, QString name, Q_INT8 nr)
 void KSVDragList::setDefaultIcon (const QPixmap& icon)
 {
   mIcon = icon;
-  
+
   for (QListViewItemIterator it (firstChild()); it.current(); ++it)
     {
 	  static_cast <KSVItem*> (it.current())->setIcon (mIcon);
@@ -413,16 +415,16 @@ Q_INT8 KSVDragList::generateNumber (const QString& label,
 
   if (high == result && result != -1 && label >= itemBelow->label())
     result = -1;
-  
+
   if (low == result && result != -1 && label <= itemAbove->label())
     result = -1;
-  
+
   return result;
 }
 
 Q_INT8 KSVDragList::generateNumber (Q_INT8 high, Q_INT8 low) const
 {
-  ASSERT (high >= low || high == -1);
+  Q_ASSERT (high >= low || high == -1);
 
   Q_INT8 result = -1;
 
@@ -444,7 +446,7 @@ Q_INT8 KSVDragList::generateNumber (Q_INT8 high, Q_INT8 low) const
 void KSVDragList::setChangedNormalColor (const QColor& col)
 {
   mChangedNormalColor = col;
-  
+
   KSVItem* item;
   for (QListViewItemIterator it (firstChild());
 	   (item = static_cast<KSVItem*> (it.current()));
@@ -457,7 +459,7 @@ void KSVDragList::setChangedNormalColor (const QColor& col)
 void KSVDragList::setChangedSelectedColor (const QColor& col)
 {
   mChangedSelectedColor = col;
-  
+
   KSVItem* item;
   for (QListViewItemIterator it (firstChild());
 	   (item = static_cast<KSVItem*> (it.current()));
@@ -501,7 +503,7 @@ void KSVDragList::startDrag ()
 {
   mItemToDrag = static_cast<KSVItem*> (currentItem());
 
-  KSVDrag* d = dragObject();
+  KSVDrag* d = dynamic_cast<KSVDrag*> (dragObject());
 
   if (d)
 	{
@@ -511,7 +513,8 @@ void KSVDragList::startDrag ()
 	}
 }
 
-KSVDrag* KSVDragList::dragObject ()
+//KSVDrag* KSVDragList::dragObject ()
+QDragObject* KSVDragList::dragObject ()
 {
   if (mItemToDrag)
 	{
@@ -546,13 +549,13 @@ void KSVDragList::clearRMList()
 bool KSVDragList::removeFromRMList (const KSVData& item)
 {
   KSVData* res = 0L;
-  
-  for (QListIterator<KSVData> it (mRMList);
+
+  for (QPtrListIterator<KSVData> it (mRMList);
 	   it.current();
 	   ++it)
 	{
 	  res = it.current();
-	  
+
 	  if (*res == item)
 		break;
 	  else
@@ -589,7 +592,7 @@ bool KSVDragList::insert (const KSVData& data, const KSVItem* where, KSVAction*&
 {
   const KSVData* above = 0L;
   const KSVData* below = 0L;
-  
+
   if (where)
 	{
 	  above = where->data();
@@ -612,7 +615,7 @@ bool KSVDragList::insert (const KSVData& data, const KSVItem* where, KSVAction*&
 		return false;
 
 	  Q_INT8 nr = generateNumber (exists->label(), below, above);
-	  
+
 	  if (nr == -1)
 		{
 		  emit cannotGenerateNumber();
@@ -692,12 +695,12 @@ bool KSVDragList::addToRMList (const KSVData& item)
 {
   KSVData* res = 0L;
 
-  for (QListIterator<KSVData> it (mRMList);
+  for (QPtrListIterator<KSVData> it (mRMList);
 	   it.current();
 	   ++it)
 	{
 	  res = it.current();
-	  
+
 	  if (*res == item)
 		break;
 	  else
@@ -718,7 +721,7 @@ void KSVDragList::setEnabled (bool enable)
   if (enable)
     clearWState (WState_ForceDisabled);
   else
-    setWState (WState_ForceDisabled);         
+    setWState (WState_ForceDisabled);
 
   if (enable)
     {
@@ -727,9 +730,9 @@ void KSVDragList::setEnabled (bool enable)
           clearWState (WState_Disabled);
           // setBackgroundFromMode(); // this is private in QWidget...
           // well it doesn't really matter in this case
-          enabledChange( TRUE );          
+          enabledChange( TRUE );
         }
-    } 
+    }
   else
     {
       if (!testWState(WState_Disabled))
@@ -761,7 +764,7 @@ void KServiceDragList::startDrag ()
 {
   mItemToDrag = static_cast<KSVItem*> (currentItem());
 
-  KSVDrag* d = dragObject();
+  KSVDrag* d = dynamic_cast<KSVDrag*> (dragObject());
 
   if (d)
 	{
