@@ -20,7 +20,7 @@ QString KListViewGroup::text(int num) const
 {
   switch(num)
   {
-     case 0: return QString("%1 ").arg(group->getGID(),6);
+     case 0: return QString::fromLatin1("%1 ").arg(group->getGID(),6);
      case 1: return group->getName();
   }
   return QString::null;
@@ -61,7 +61,7 @@ void KGroupView::init()
   setAllColumnsShowFocus(true);
   addColumn(i18n("GID"));
   setColumnAlignment(0, AlignRight);
-  addColumn(i18n("Group name"));
+  addColumn(i18n("Group Name"));
 }
 
 KGroup *KGroupView::getCurrentGroup() {
