@@ -4,7 +4,7 @@
 #include "ftpaccess.h"
 #include "LoggingBase.h"
 
-#include <kapp.h>
+#include <kapplication.h>
 
 class Logging : public LoggingBase {
 	Q_OBJECT
