@@ -3,7 +3,7 @@
 
 #include "ftpaccess.h"
 #include "UploadsBase.h"
-#include <kapp.h>
+#include <kapplication.h>
 
 class Uploads : public UploadsBase {
 	Q_OBJECT
