@@ -1466,7 +1466,7 @@ ostream &operator<<(ostream &os, ftpclass &f)
 	}
 	ftplimit *fl=0;
 	while((fl=f.getNextLimit(fl)))
-		os << "limit " << f.getName().latin1() << "\t" << fl;
+		os << "limit " << f.getName().latin1() << "\t" << *fl;
 	return os;
 }
 ostream &operator <<(ostream &os, ftplimit &f)
