@@ -10,7 +10,7 @@
 #include "Ratios.h"
 #include "Uploads.h"
 #include "Virtual.h"
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmainwindow.h>
 #include <klocale.h>
 #include <qtabwidget.h>
