@@ -18,7 +18,7 @@
 
 #include "kxdata.h"
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qfile.h>
 #include <qtextstream.h>
 
