@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** $Id: xfree4probe.cpp,v 1.3 2002/04/15 09:40:17 hausmann Exp $
+** $Id: xfree4probe.cpp,v 1.3.2.1 2003/03/13 00:05:22 rnolden Exp $
 **
 ** Copyright (C) 1999 Calderasystems, Inc
 ** All rights reserved.
@@ -31,7 +31,7 @@
 
 #include <kprocess.h>
 #include <kdebug.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 #include "ddcprobe.h"
 #include "ltemplate.h"
