@@ -27,7 +27,7 @@ String const ConfigFile::get(String const &key, String const &dflt, bool const &
 	String s=grep("[ \t]*" + key + "[ \t]*=").simplifyWhiteSpace();
 	if(s.empty())
 		return dflt;
-	s=s.mid(s.locate("=")+2);
+	s=s.mid(s.locate("=")+2).simplifyWhiteSpace();
 	if(unquote) {
 		if(s.chr(0)=='"')
 			s=s.mid(2);
